==> core-io-1.0.0-sources.jar: com/couchbase/client/core/service/ServiceType.java <==
/**
 * Copyright (C) 2014 Couchbase, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALING
 * IN THE SOFTWARE.
 */
package com.couchbase.client.core.service;

/**
 * Represents the different {@link ServiceType}s and how they map onto buckets.
 *
 * @author Michael Nitschinger
 * @since 1.0
 */
public enum ServiceType {

    /**
     * Views and Design Documents.
     */
    VIEW(BucketServiceMapping.ONE_FOR_ALL),

    /**
     * Key/Value type operations.
     */
    BINARY(BucketServiceMapping.ONE_BY_ONE),

    /**
     * Query (N1QL) operations.
     */
    QUERY(BucketServiceMapping.ONE_FOR_ALL),

    /**
     * HTTP config operations.
     */
    CONFIG(BucketServiceMapping.ONE_FOR_ALL);

    private final BucketServiceMapping mapping;

    private ServiceType(BucketServiceMapping mapping) {
        this.mapping = mapping;
    }

    public BucketServiceMapping mapping() {
        return mapping;
    }
}

==> core-io-1.2.3-sources.jar: com/couchbase/client/core/service/ServiceType.java <==
/**
 * Copyright (C) 2014 Couchbase, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALING
 * IN THE SOFTWARE.
 */
package com.couchbase.client.core.service;

/**
 * Represents the different {@link ServiceType}s and how they map onto buckets.
 *
 * @author Michael Nitschinger
 * @since 1.0
 */
public enum ServiceType {

    /**
     * Views and Design Documents.
     */
    VIEW(BucketServiceMapping.ONE_FOR_ALL),

    /**
     * Key/Value type operations.
     */
    BINARY(BucketServiceMapping.ONE_BY_ONE),

    /**
     * Query (N1QL) operations.
     */
    QUERY(BucketServiceMapping.ONE_FOR_ALL),

    /**
     * HTTP config operations.
     */
    CONFIG(BucketServiceMapping.ONE_FOR_ALL),

    /**
     * DCP operations
     */
    DCP(BucketServiceMapping.ONE_BY_ONE);

    private final BucketServiceMapping mapping;

    private ServiceType(BucketServiceMapping mapping) {
        this.mapping = mapping;
    }

    public BucketServiceMapping mapping() {
        return mapping;
    }
}
